@@ -18,7 +18,7 @@ __PACKAGE__->attr('home', default => sub { Mojo::Home->new });
 __PACKAGE__->attr('log',  default => sub { Mojo::Log->new });
 
 # Oh, so they have internet on computers now!
-our $VERSION = '0.991242';
+our $VERSION = '0.991244';
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -52,26 +52,42 @@ Mojo - The Web In A Box!
 
     use base 'Mojo';
 
+    # All the complexities of CGI, FastCGI and HTTP get reduced to a
+    # single method call!
     sub handler {
         my ($self, $tx) = @_;
 
-        # Hello world!
+        # Request
+        my $method = $tx->req->method;
+        my $path   = $tx->req->url->path;
+
+        # Response
         $tx->res->headers->content_type('text/plain');
-        $tx->res->body('Congratulations, your Mojo is working!');
+        $tx->res->body("$method request for $path!");
     }
 
 =head1 DESCRIPTION
 
-L<Mojo> is a collection of libraries and example web frameworks for web
-framework developers.
+L<Mojo> provides a minimal interface between web servers and Perl web
+frameworks.
 
-If you are searching for a higher level MVC web framework you should take a
-look at L<Mojolicious>.
+Also included in the distribution are two MVC web frameworks named
+L<Mojolicious> and L<Mojolicious::Lite>.
 
-Don't be scared by the amount of different modules in the distribution, they
-are all very loosely coupled.
-You can just pick the ones you like and ignore the rest, there is no
-tradeoff.
+Currently there are no requirements besides Perl 5.8.1.
+
+    .------------------------------------------------------------.
+    |                                                            |
+    |   Application  .-------------------------------------------'
+    |                | .-------------------. .-------------------.
+    |                | |    Mojolicious    | | Mojolicious::Lite |
+    '----------------' '-------------------' '-------------------'
+    .------------------------------------------------------------.
+    |                           Mojo                             |
+    '------------------------------------------------------------'
+    .------------------. .------------------. .------------------.
+    |        CGI       | |      FastCGI     | |     HTTP 1.1     |
+    '------------------' '------------------' '------------------'
 
 For userfriendly documentation see L<Mojo::Manual>.
 
@@ -138,6 +154,8 @@ Sebastian Riedel, C<sri@cpan.org>.
 
 In alphabetical order:
 
+Adam Kennedy
+
 Anatoly Sharifulin
 
 Andreas Koenig
@@ -168,6 +186,8 @@ Jesse Vincent
 
 Kazuhiro Shibuya
 
+Kevin Old
+
 Lars Balker Rasmussen
 
 Leon Brocard
@@ -184,6 +204,8 @@ Pascal Gaudette
 
 Pedro Melo
 
+Pierre-Yves Ritschard
+
 Randal Schwartz
 
 Robert Hicks
