@@ -11,24 +11,37 @@ use bytes;
 
 __PACKAGE__->attr('raw_length', default => 0);
 
-sub new {
-    my $self = shift->SUPER::new();
-    $self->add_chunk(join '', @_) if @_;
-    $self->{buffer} ||= '';
+sub add_chunk {
+    my ($self, $chunk) = @_;
+
+    # Shortcut
+    return $self unless $chunk;
+
+    # Raw length
+    $self->raw_length($self->raw_length + length $chunk);
+
+    # Store
+    $self->{_buffer} ||= '';
+    $self->{_buffer} .= $chunk;
+
     return $self;
 }
 
-sub add_chunk {
+sub contains {
     my ($self, $chunk) = @_;
-    $self->raw_length($self->raw_length + length $chunk);
-    $self->{buffer} .= $chunk;
-    return $self;
+
+    # Search
+    return index $self->{_buffer} || '', $chunk;
 }
 
 sub empty {
-    my $self   = shift;
-    my $buffer = $self->{buffer};
-    $self->{buffer} = '';
+    my $self = shift;
+
+    # Cleanup
+    my $buffer = $self->{_buffer};
+    my $x      = '';
+    $self->{_buffer} = '';
+
     return $buffer;
 }
 
@@ -36,30 +49,32 @@ sub get_line {
     my $self = shift;
 
     # No full line in buffer
-    return undef unless $self->{buffer} =~ /\x0d?\x0a/;
+    return unless ($self->{_buffer} || '') =~ /\x0d?\x0a/;
 
     # Locate line ending
-    my $pos = index $self->{buffer}, "\x0a";
+    my $pos = index $self->{_buffer}, "\x0a";
 
     # Extract line and ending
-    my $line = substr $self->{buffer}, 0, $pos + 1, '';
+    my $line = substr $self->{_buffer}, 0, $pos + 1, '';
     $line =~ s/(\x0d?\x0a)\z//;
 
     return $line;
 }
 
-sub length {
-    my $self = shift;
-    $self->{buffer} ||= '';
-    return length $self->{buffer};
-}
+sub length { length(shift->{_buffer} || '') }
 
 sub remove {
-    my ($self, $length) = @_;
-    return substr $self->{buffer}, 0, $length, '';
+    my ($self, $length, $chunk) = @_;
+
+    # Chunk to replace?
+    $chunk ||= '';
+
+    # Extract and replace
+    $self->{_buffer} ||= '';
+    return substr $self->{_buffer}, 0, $length, $chunk;
 }
 
-sub to_string { shift->{buffer} || '' }
+sub to_string { shift->{_buffer} || '' }
 
 1;
 __END__
@@ -72,7 +87,7 @@ Mojo::Buffer - A Simple In-Memory Buffer
 
     use Mojo::Buffer;
 
-    my $buffer = Mojo::Buffer->new('foo');
+    my $buffer = Mojo::Buffer->new;
     $buffer->add_chunk('bar');
     my $foo = $buffer->remove(3);
     my $bar = $buffer->empty;
@@ -80,64 +95,49 @@ Mojo::Buffer - A Simple In-Memory Buffer
 =head1 DESCRIPTION
 
 L<Mojo::Buffer> is a simple in-memory buffer.
-Functionality includes keeping track of the cumulative raw character length
-that has been in the buffer.
-Content may removed from the buffer by line or character count.
 
 =head1 ATTRIBUTES
 
-=head2 C<length>
-
-    my $length = $buffer->length;
+L<Mojo::Buffer> implements the following attributes.
 
 =head2 C<raw_length>
 
-    my $raw_length = $buffer->raw_length;
-
-Returns the cumulative length of the buffer.
-It never decreases.
+    my $length = $buffer->raw_length;
+    $buffer    = $buffer->raw_length(23);
 
 =head1 METHODS
 
 L<Mojo::Buffer> inherits all methods from L<Mojo::Base> and implements
 the following new ones.
 
-=head2 C<new>
-
-    my $buffer = Mojo::Buffer->new;
-    my $buffer = Mojo::Buffer->new('foobarbaz');
-
-Returns a new L<Mojo::Buffer> object, and possibly adds content to it.
-
 =head2 C<add_chunk>
 
     $buffer = $buffer->add_chunk('foo');
 
-Returns the invocant and adds additional content to the buffer.
+=head2 C<contains>
+
+    my $position = $buffer->contains('something');
 
 =head2 C<empty>
 
-    my $string = $buffer->empty;
-
-Returns the whole content of the buffer and empties it.
+    my $chunk = $buffer->empty;
 
 =head2 C<get_line>
 
    my $line = $buffer->get_line;
 
-Returns a whole line if a C<newline> is present in the buffer or undef, even
-if there is content in the buffer.
+=head2 C<length>
+
+    my $length = $buffer->length;
 
 =head2 C<remove>
 
-    my $string = $buffer->remove(4);
-
-Returns and removes a specific number of bytes from the buffer.
+    my $chunk = $buffer->remove(4);
+    my $chunk = $buffer->remove(4, 'abcd');
 
 =head2 C<to_string>
 
     my $string = $buffer->to_string;
-
-Returns the whole buffer content at once.
+    my $string = "$buffer";
 
 =cut
