@@ -81,12 +81,6 @@ my (%ORDERED_HEADERS, %NORMALCASE_HEADERS);
     }
 }
 
-sub new {
-    my $self = shift->SUPER::new(@_);
-    $self->{_headers} = {};
-    return $self;
-}
-
 sub add {
     my $self = shift;
     my $name = shift;
@@ -102,9 +96,6 @@ sub add {
     }
     $name = $lcname;
 
-    # Initialize header
-    $self->{_headers}->{$name} ||= [];
-
     # Filter values
     my @values;
     for my $v (@_) {
@@ -121,6 +112,7 @@ sub add {
     }
 
     # Add line
+    $self->{_headers} ||= {};
     push @{$self->{_headers}->{$name}}, @values;
 
     return $self;
@@ -166,7 +158,8 @@ sub header {
 
     # Get
     my $headers;
-    return undef unless $headers = $self->{_headers}->{lc $name};
+    return unless $self->{_headers};
+    return unless $headers = $self->{_headers}->{lc $name};
 
     # String
     unless (wantarray) {
@@ -185,12 +178,14 @@ sub header {
     return @$headers;
 }
 
-sub host { shift->header('Host', @_) }
+sub host     { shift->header('Host',     @_) }
+sub location { shift->header('Location', @_) }
 
 sub names {
     my $self = shift;
 
     # Names
+    return [] unless $self->{_headers};
     my @names = keys %{$self->{_headers}};
 
     # Sort
@@ -209,8 +204,10 @@ sub names {
 }
 
 sub parse {
-    my $self = shift;
-    $self->buffer->add_chunk(join '', @_) if @_;
+    my ($self, $chunk) = @_;
+
+    # Buffer
+    $self->buffer->add_chunk($chunk);
 
     # Parse headers
     $self->state('headers') if $self->is_state('start');
@@ -246,7 +243,7 @@ sub parse {
             return $self->buffer;
         }
     }
-    return undef;
+    return;
 }
 
 sub proxy_authorization { shift->header('Proxy-Authorization', @_) }
@@ -255,6 +252,7 @@ sub remove {
     my ($self, $name) = @_;
 
     # Delete
+    return $self unless $self->{_headers};
     delete $self->{_headers}->{lc $name};
 
     return $self;
@@ -336,6 +334,11 @@ implements the following new ones.
     my $host = $headers->host;
     $headers = $headers->host('127.0.0.1');
 
+=head2 C<location>
+
+    my $location = $headers->location;
+    $headers     = $headers->location('http://127.0.0.1/foo');
+
 =head2 C<proxy_authorization>
 
     my $proxy_authorization = $headers->proxy_authorization;
@@ -381,17 +384,10 @@ implements the following new ones.
 L<Mojo::Headers> inherits all methods from L<Mojo::Stateful> and implements
 the following new ones.
 
-=head2 C<new>
-
-    my $headers = Mojo::Headers->new;
-
 =head2 C<add>
 
     $headers = $headers->add('Content-Type', 'text/plain');
 
-Returns the invocant.
-Appends a new line to the header.
-
 =head2 C<to_string>
 
 =head2 C<build>
