@@ -36,10 +36,10 @@ sub dispatch {
 }
 
 sub serve {
-    my ($self, $c, $path) = @_;
+    my ($self, $c, $rel) = @_;
 
     # Append path to root
-    $path = File::Spec->catfile($self->root, split('/', $path));
+    my $path = File::Spec->catfile($self->root, split('/', $rel));
 
     # Extension
     $path =~ /\.(\w+)$/;
@@ -52,7 +52,7 @@ sub serve {
     if (-f $path) {
 
         # Log
-        $c->app->log->debug(qq/Serving static file "$path"./);
+        $c->app->log->debug(qq/Serving static file "$rel"./);
 
         my $res = $c->res;
         if (-r $path) {
@@ -72,7 +72,7 @@ sub serve {
                     $res->headers->remove('Content-Type');
                     $res->headers->remove('Content-Length');
                     $res->headers->remove('Content-Disposition');
-                    return 0;
+                    return;
                 }
             }
 
@@ -91,7 +91,7 @@ sub serve {
             $res->headers->content_type($type);
             $res->content->file->path($path);
 
-            return 0;
+            return;
         }
 
         # Exists, but is forbidden
@@ -101,7 +101,7 @@ sub serve {
             $c->app->log->debug('File forbidden.');
 
             $res->code(403);
-            return 0;
+            return;
         }
     }
 
@@ -113,7 +113,7 @@ sub serve_404 { shift->serve_error(shift, 404) }
 sub serve_500 { shift->serve_error(shift, 500) }
 
 sub serve_error {
-    my ($self, $c, $code, $path) = @_;
+    my ($self, $c, $code, $rel) = @_;
 
     # Shortcut
     return 1 unless $c && $code;
@@ -124,16 +124,16 @@ sub serve_error {
     $res->code($code);
 
     # Default to "code.html"
-    $path ||= "$code.html";
+    $rel ||= "$code.html";
 
     # Append path to root
-    $path = File::Spec->catfile($self->root, split('/', $path));
+    my $path = File::Spec->catfile($self->root, split('/', $rel));
 
     # File
     if (-r $path) {
 
         # Log
-        $c->app->log->debug(qq/Serving error file "$path"./);
+        $c->app->log->debug(qq/Serving error file "$rel"./);
 
         # File
         $res->content(Mojo::Content->new(file => Mojo::File->new));
@@ -182,7 +182,7 @@ EOF
 EOF
     }
 
-    return 0;
+    return;
 }
 
 1;
@@ -208,34 +208,23 @@ L<MojoX::Dispatcher::Static> is a dispatcher for static files.
 
 =head2 ATTRIBUTES
 
+L<MojoX::Dispatcher::Static> implements the following attributes.
+
 =head2 C<prefix>
 
     my $prefix  = $dispatcher->prefix;
     $dispatcher = $dispatcher->prefix('/static');
 
-Returns the path prefix if called without arguments.
-Returns the invocant if called with arguments.
-If defined, files will only get served for url paths beginning with this
-prefix.
-
 =head2 C<types>
 
     my $types   = $dispatcher->types;
     $dispatcher = $dispatcher->types(MojoX::Types->new);
 
-Returns a L<Mojo::Types> object if called without arguments.
-Returns the invocant if called with arguments.
-If no type can be determined, C<text/plain> will be used.
-
 =head2 C<root>
 
     my $root    = $dispatcher->root;
     $dispatcher = $dispatcher->root('/foo/bar/files');
 
-Returns the root directory from which files get served if called without
-arguments.
-Returns the invocant if called with arguments.
-
 =head1 METHODS
 
 L<MojoX::Dispatcher::Static> inherits all methods from L<Mojo::Base> and
@@ -245,23 +234,10 @@ implements the follwing the ones.
 
     my $success = $dispatcher->dispatch($c);
 
-Returns false if a file matching the request could be found and a response be
-prepared.
-Returns true otherwise.
-Expects a L<MojoX::Context> object as first argument.
-
 =head2 C<serve>
 
     my $success = $dispatcher->serve($c, 'foo/bar.html');
 
-Returns false if a readable file could be found under C<root> and a response
-be prepared.
-Returns true otherwise.
-Expects a L<MojoX::Context> object and a path as arguments.
-If no type can be determined, C<text/plain> will be used.
-A C<Last-Modified> header will always be set according to the last modified
-time of the file.
-
 =head2 C<serve_404>
 
     my $success = $dispatcher->serve_404($c);
