@@ -7,20 +7,8 @@ use warnings;
 
 use base 'Mojo::Scripts';
 
-__PACKAGE__->attr('message', default => <<'EOF');
-Welcome to the Mojolicious Web Framework!
-
-HINT: In case you don't know what you are doing here try the manual!
-    perldoc Mojo::Manual
-    perldoc Mojo::Manual::GettingStarted
-
-This is the interactive script interface, the syntax is very simple.
-    mojolicious <script> <options>
-
-Below you will find a list of available scripts with descriptions.
-
-EOF
-__PACKAGE__->attr('namespace', default => 'Mojolicious::Script');
+__PACKAGE__->attr('namespaces',
+    default => sub { [qw/Mojolicious::Script Mojo::Script/] });
 
 # One day a man has everything, the next day he blows up a $400 billion
 # space station, and the next day he has nothing. It makes you think.
@@ -48,15 +36,10 @@ L<Mojolicous::Scripts> is a interactive script interface.
 L<Mojolicious::Scripts> inherits all attributes from L<Mojo::Scripts> and
 implements the following new ones.
 
-=head2 C<message>
+=head2 C<namespaces>
 
-    my $message = $scripts->message;
-    $scripts    = $scripts->message('Mojolicious!');
-
-=head2 C<namespace>
-
-    my $namespace = $scripts->namespace;
-    $scripts      = $scripts->namespace('Mojolicious::Scripts');
+    my $namespaces = $scripts->namespaces;
+    $scripts       = $scripts->namespaces(['Mojolicious::Scripts']);
 
 =head1 METHODS
 
